package org.rcisoft.app.appMemInfo.controller;


/*固定导入*/

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.Parameters;
import io.swagger.v3.oas.annotations.media.Schema;
import jakarta.servlet.http.HttpServletResponse;
import org.rcisoft.business.memInfo.entity.MemInfo;
import org.rcisoft.business.memInfo.service.MemInfoService;
import org.rcisoft.core.anno.CyEncryptSm4Anno;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.component.CyGlobal;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.result.enums.CyResSysExcEnum;
import org.rcisoft.core.service.CyFileStorageService;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.rcisoft.core.util.CyResultGenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.validation.Valid;
import java.util.Arrays;
import java.util.List;

/**
* Created by cy on 2024年12月20日 下午3:35:34.
*/
@RestController
@RequestMapping("/app")
public class AppMemInfoController extends CyPaginationController<MemInfo> {


    @Autowired
    private MemInfoService memInfoServiceImpl;

    @Autowired
    private CyGlobal cyGlobal;

    @Autowired
    private CyFileStorageService cyFileStorageService;

//    @PreAuthorize("@cyPerm.hasPerm('mem:info:add')")
    @CyOpeLogAnno(title = "system-会员表管理-新增会员表", businessType = CyLogTypeEnum.INSERT)
    @Operation(summary="添加会员表", description="添加会员表")
    @PostMapping(value = "/open/memInfo/add")
    @CyEncryptSm4Anno
    public CyResult add( MemInfo memInfo) {
        CyPersistModel data = memInfoServiceImpl.persist(memInfo);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        memInfo);
    }

    @CyOpeLogAnno(title = "system-会员表管理-校验手机号", businessType = CyLogTypeEnum.OTHER)
    @Operation(summary="校验手机号", description="校验手机号")
    @PostMapping(value = "/open/memInfo/checkInfo")
    @CyEncryptSm4Anno
    public CyResult checkInfo(@Valid MemInfo memInfo) {
        return CyResultGenUtil.genSuccessResult(memInfoServiceImpl.checkInfo(memInfo));
    }


    @CyOpeLogAnno(title = "system-会员表管理-查询会员表", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="查询单一会员表", description="查询单一会员表")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = true,  schema = @Schema(type = "string"))})
    @GetMapping("/open/memInfo/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                memInfoServiceImpl.findById(businessId));
    }

    @CyOpeLogAnno(title = "system-会员表管理-查询会员表", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="分页查询会员表集合", description="分页查询会员表集合")
    @GetMapping(value = "/open/memInfo/list")
//    @CyEncryptSm4Anno
    public CyGridModel listByPagination(MemInfo memInfo) {
        memInfoServiceImpl.findAllByPagination(getPaginationUtility(), memInfo);
        return getGridModelResponse();
    }


    /**
     * 文件上传new （2.0）
     *
     * @param file
     * @return
     */
    @Operation(summary = "文件上传", description = "文件上传")
    @Parameters({@Parameter(name = "file", description = "文件", required = true)})
    @PostMapping(value = "/open/fileUpload")
    @ResponseBody
    public CyResult fileUpload(@RequestParam("file") MultipartFile file, @RequestParam("temp") String temp, @RequestParam(name = "bucket", required = false) String bucket) {
        //文件上传限制
        String[] split = cyGlobal.getFileUploadFormatRestrictions().split(",");
        if (file==null || Arrays.stream(split).anyMatch(file.getOriginalFilename()::contains)){
            throw new CyServiceException(CyResSysExcEnum.FILE_STORAGE_ERROR);
        };
        return CyResultGenUtil.builder(new CyPersistModel(1),
                CyMessCons.MESSAGE_ALERT_SUCCESS,
                CyMessCons.MESSAGE_ALERT_ERROR,
                cyFileStorageService.filePath(file, temp, bucket));
    }
}
